Title: [192173] trunk
Revision
192173
Author
n_w...@apple.com
Date
2015-11-09 13:16:14 -0800 (Mon, 09 Nov 2015)

Log Message

AX: Input type: time is not accessible on iOS
https://bugs.webkit.org/show_bug.cgi?id=150984

Reviewed by Chris Fleizach.

Source/WebCore:

Exposed input type: time as popup button on iOS.

Test: accessibility/ios-simulator/input-type-time.html

* accessibility/AccessibilityRenderObject.cpp:
(WebCore::AccessibilityRenderObject::determineAccessibilityRole):

LayoutTests:

* accessibility/ios-simulator/input-type-time-expected.txt: Added.
* accessibility/ios-simulator/input-type-time.html: Added.

Modified Paths

Added Paths

Diff

Modified: trunk/LayoutTests/ChangeLog (192172 => 192173)


--- trunk/LayoutTests/ChangeLog	2015-11-09 20:29:54 UTC (rev 192172)
+++ trunk/LayoutTests/ChangeLog	2015-11-09 21:16:14 UTC (rev 192173)
@@ -1,3 +1,13 @@
+2015-11-09  Nan Wang  <n_w...@apple.com>
+
+        AX: Input type: time is not accessible on iOS
+        https://bugs.webkit.org/show_bug.cgi?id=150984
+
+        Reviewed by Chris Fleizach.
+
+        * accessibility/ios-simulator/input-type-time-expected.txt: Added.
+        * accessibility/ios-simulator/input-type-time.html: Added.
+
 2015-11-09  Jiewen Tan  <jiewen_...@apple.com>
 
         Null dereference loading Blink layout test editing/inserting/insert-html-crash-01.html

Added: trunk/LayoutTests/accessibility/ios-simulator/input-type-time-expected.txt (0 => 192173)


--- trunk/LayoutTests/accessibility/ios-simulator/input-type-time-expected.txt	                        (rev 0)
+++ trunk/LayoutTests/accessibility/ios-simulator/input-type-time-expected.txt	2015-11-09 21:16:14 UTC (rev 192173)
@@ -0,0 +1,12 @@
+
+This tests that input type: time is accessible on iOS.
+
+On success, you will see a series of "PASS" messages, followed by "TEST COMPLETE".
+
+
+PASS timeinput.description is 'AXLabel: (Between: 07:00 AM-09:00 AM)'
+PASS timeinput.isIgnored is false
+PASS successfullyParsed is true
+
+TEST COMPLETE
+

Added: trunk/LayoutTests/accessibility/ios-simulator/input-type-time.html (0 => 192173)


--- trunk/LayoutTests/accessibility/ios-simulator/input-type-time.html	                        (rev 0)
+++ trunk/LayoutTests/accessibility/ios-simulator/input-type-time.html	2015-11-09 21:16:14 UTC (rev 192173)
@@ -0,0 +1,33 @@
+<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML//EN">
+<html>
+<head>
+<script>
+var successfullyParsed = false;
+</script>
+<script src=""
+</head>
+<body id="body">
+
+<input id="timeinput" type="time" aria-label="(Between: 07:00 AM-09:00 AM)" min="07:00" max="09:00" step="300" placeholder="00:00 AM">
+
+<p id="description"></p>
+<div id="console"></div>
+
+<script>
+
+    description("This tests that input type: time is accessible on iOS.");
+
+    if (window.accessibilityController) {
+
+        var timeinput = accessibilityController.accessibleElementById("timeinput");
+        shouldBe("timeinput.description", "'AXLabel: (Between: 07:00 AM-09:00 AM)'");
+        shouldBeFalse("timeinput.isIgnored");
+    }
+
+    successfullyParsed = true;
+</script>
+
+<script src=""
+</body>
+</html>
+

Modified: trunk/Source/WebCore/ChangeLog (192172 => 192173)


--- trunk/Source/WebCore/ChangeLog	2015-11-09 20:29:54 UTC (rev 192172)
+++ trunk/Source/WebCore/ChangeLog	2015-11-09 21:16:14 UTC (rev 192173)
@@ -1,3 +1,17 @@
+2015-11-09  Nan Wang  <n_w...@apple.com>
+
+        AX: Input type: time is not accessible on iOS
+        https://bugs.webkit.org/show_bug.cgi?id=150984
+
+        Reviewed by Chris Fleizach.
+
+        Exposed input type: time as popup button on iOS.
+
+        Test: accessibility/ios-simulator/input-type-time.html
+
+        * accessibility/AccessibilityRenderObject.cpp:
+        (WebCore::AccessibilityRenderObject::determineAccessibilityRole):
+
 2015-11-09  Jiewen Tan  <jiewen_...@apple.com>
 
         Null dereference loading Blink layout test editing/inserting/insert-html-crash-01.html

Modified: trunk/Source/WebCore/accessibility/AccessibilityRenderObject.cpp (192172 => 192173)


--- trunk/Source/WebCore/accessibility/AccessibilityRenderObject.cpp	2015-11-09 20:29:54 UTC (rev 192172)
+++ trunk/Source/WebCore/accessibility/AccessibilityRenderObject.cpp	2015-11-09 21:16:14 UTC (rev 192173)
@@ -2553,9 +2553,9 @@
             return RadioButtonRole;
         if (input.isTextButton())
             return buttonRoleType();
         // On iOS, the date field is a popup button. On other platforms this is a text field.
 #if PLATFORM(IOS)
-        if (input.isDateField())
+        if (input.isDateField() || input.isTimeField())
             return PopUpButtonRole;
 #endif
         
@@ -2553,9 +2553,9 @@
         if (input.isTextButton())
             return buttonRoleType();
-        // On iOS, the date field is a popup button. On other platforms this is a text field.
+        // On iOS, the date field and time field are popup buttons. On other platforms they are text fields.
 #if PLATFORM(IOS)
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to